Module machine

Module machine 

Structs

MerkleProofVariable
RootPublicValues
SP1CompressRootVerifierWithVKey
A program to verify a single recursive proof representing a complete proof of program execution.
SP1CompressVerifier
A program to verify a batch of recursive proofs and aggregate their public values.
SP1CompressWithVKeyVerifier
SP1CompressWithVKeyWitnessValues
An input layout for the verifier of the proof shape phase of the compress stage.
SP1CompressWithVKeyWitnessVariable
Witness layout for the verifier of the proof shape phase of the compress stage.
SP1DeferredVerifier
SP1DeferredWitnessValues
SP1DeferredWitnessVariable
SP1MerkleProofVerifier
A program to verify a batch of recursive proofs and aggregate their public values.
SP1MerkleProofWitnessValues
An input layout for the reduce verifier.
SP1MerkleProofWitnessVariable
Witness layout for the compress stage verifier.
SP1NormalizeWitnessValues
A struct to contain the inputs to the normalize program.
SP1RecursionWitnessVariable
SP1RecursiveVerifier
A program for recursively verifying a batch of SP1 proofs.
SP1ShapedWitnessValues
An input layout for the shard proofs that have been normalized to a standard shape.
SP1ShapedWitnessVariable
Witness layout for the compress stage verifier.
SP1WrapVerifier
A program to verify a single recursive proof representing a complete proof of program execution.

Enums

PublicValuesOutputDigest

Type Aliases

InnerChallenge
InnerVal
JC
VkAndProof