pub struct SP1RecursiveVerifier<C: Config> { /* private fields */ }Expand description
A program for recursively verifying a batch of SP1 proofs.
Implementations
Sourceimpl<C> SP1RecursiveVerifier<C>
impl<C> SP1RecursiveVerifier<C>
Sourcepub fn verify(
builder: &mut Builder<C>,
machine: &RecursiveShardVerifier<SP1GlobalContext, RiscvAir<SP1Field>, C>,
input: SP1RecursionWitnessVariable<C, SP1GlobalContext>,
)
pub fn verify( builder: &mut Builder<C>, machine: &RecursiveShardVerifier<SP1GlobalContext, RiscvAir<SP1Field>, C>, input: SP1RecursionWitnessVariable<C, SP1GlobalContext>, )
Verify a batch of SP1 shard proofs and aggregate their public values.
This program represents a first recursive step in the verification of an SP1 proof consisting of one or more shards. Each shard proof is verified and its public values are turned into the recursion public values, which will be aggregated in compress.
Constraints
Verifying the core shard proofs.
For each shard, the verifier asserts the correctness of the shard proof which is composed of verifying the polynomial commitment’s proof for openings and verifying the constraints.
Verifing the first shard constraints.
The first shard has some additional constraints for initialization.